##' Calculate the energy requirements of a village
##'
##' Calculate the energy requirements of a village based on a given
##' population size
##'
##' This functions is a wrapper for more comprehensive functions calculating the nutritional (kcal) requirements of a village; These are not implemented yet; Note that more comprehensive approaches, e.g. considering a death-table of a village, require a lot more data that is often not available
##'
##' @title setup_population
##' @param population The number of people living in a village
##' @param mode The calculation mode; currently only "simplified" (the default) and "medium" is implemented; further modes will be added soon and require further input data
##' simplified approach takes the mean of empirical values of daily kcal requirements for active females and males in the age between 10 and 50 (source for daily requirements:  \url{http://www.cnpp.usda.gov/sites/default/files/usda_food_patterns/EstimatedCalorieNeedsPerDayTable.pdf})
##' @param kcal_requirement optional; default NULL
##' @return A list with the elements: Population, KcalHuman, KcalHumanYear, KcalVillageYear
##' @export
setup_population <- function(population,
                             mode = "simplified",
                             kcal_requirement = NULL
                             ) {

  if (mode == "simplified") {
    data(kcal_req_age, package = "LandUseQuantifieR")

    kcal_human <- kcal_req_age %>%
      dplyr::filter(as.numeric(age) > 10,
                    as.numeric(age) < 50) %>%
      dplyr::select(male_active, female_active) %>%
      sapply(FUN = mean) %>%
      mean(.)
  }

  if (mode == "manual") {
    if(!is.null(kcal_requirement)) {
      kcal_human <- kcal_requirement
    } else {
      stop("kcal_requirement has to be given as single value.")
    }
  }

  kcal_human_year <- kcal_human * 365
  kcal_village_year <- kcal_human_year * population

  return(list(
    "Population" = population,
    "KcalHuman" = kcal_human,
    "KcalHumanYear" = kcal_human_year,
    "KcalVillageYear" = kcal_village_year))

}

##' Calculate the energy requirements of a village based on number, age, sex and activity level
##'
##' Calculate the energy requirements of a village based on number, age, sex and activity level based on a data.frame containing these information
##'
##' This functions uses more detailed demographic informations to caluculate the yearly kcal requirements of a village. To be able to do this, the data has to be stored in a data.frame.
##'
##' @title setup_population_detailed_kcal
##' @param population A data.frame containing informations about number, age, sex and activity level of each demographic group
##' @return A list with the elements: Population, KcalHumanYear, KcalVillageYear
##'
##' @importFrom dplyr "%>%"
##' @importFrom dplyr "mutate"
##' @importFrom dplyr "summarize"
##'
##' @export

setup_population_detailed_kcal <- function(population
                                      ) {
  data(kcal_req_detailed,  package = "LandUseQuantifieR")

  population$age <- as.character(population$age)
  population$sex <- as.character(population$sex)
  population$activity <- as.character(population$activity)

  population_df <- population

  tmp <- dplyr::left_join(population_df, kcal_req_detailed,
                          by = c("age", "sex", "activity"))
  village_kcal <- tmp %>%
    mutate(total_kcal = number * kcal_req) %>%
    summarize(sum_village_kcal = sum(total_kcal, na.rm = TRUE))

  population_number <- dplyr::summarize(population_df, sum_number = sum(number,  na.rm = TRUE))

  kcal_village_year <- village_kcal$sum_village_kcal * 365

  kcal_human_year <- kcal_village_year/population_number$sum_number

  return(list(
    "Population" = population_number$sum_number,
    "KcalVillage" = village_kcal$sum_village_kcal,
    "KcalHumanYear" = kcal_human_year,
    "KcalVillageyear" = kcal_village_year))

}

##' Setup the crop and legume diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_crops
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_crops <- function(population,
                             food_df,
                             kcal_req_human_year) {



  proportion_df <- crop_selector_kcal(food_df)

if (ncol(food_df) < 3) {

  diet <- proportion_df %>%
    dplyr::mutate(
      Kcal_requirements_percapita = c(
        Proportion * kcal_req_human_year
      ),
      area_req_percapita = c(
        Kcal_requirements_percapita / ((productivity * calories) * (1 - (proportion_df$planting + proportion_df$waste_loss + proportion_df$storage)))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units
      )

  return(list(AreaCrops = sum(diet$area_req_village),
              diet = diet))

} else {

  diet <- proportion_df %>%
    dplyr::mutate(
      Kcal_requirements_percapita = c(
        Proportion * kcal_req_human_year
      ),
      area_req_percapita = c(
        Kcal_requirements_percapita / ((productivity * calories) * (1 - (as.numeric(proportion_df$Planting) + as.numeric(proportion_df$Waste_loss) + as.numeric(proportion_df$Storage))))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units)

  return(list(AreaCrops = sum(diet$area_req_village),
              diet = diet))


}

}

##' Setup the general arboriculture and gathered plants diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_arbori_gather
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_arbori_gather <- function(population,
                                     food_df,
                                     kcal_req_human_year) {

  proportion_df <- arbori_selector_kcal(food_df)


if (ncol(food_df) < 3) {

  diet <- proportion_df %>%
    dplyr::mutate(
      Kcal_requirements_percapita = c(
        Proportion * kcal_req_human_year
      ),
      area_req_percapita = c(
        Kcal_requirements_percapita / ((productivity * calories) * (1 - (proportion_df$planting + proportion_df$waste_loss + proportion_df$storage)))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units
      )

  return(list(AreaArboriGather = sum(diet$area_req_village),
              diet = diet))

} else {

  diet <- proportion_df %>%
    dplyr::mutate(
      Kcal_requirements_percapita = c(
        Proportion * kcal_req_human_year
      ),
      area_req_percapita = c(
        Kcal_requirements_percapita / ((productivity * calories) * (1 - (as.numeric(proportion_df$Planting) + as.numeric(proportion_df$Waste_loss) + as.numeric(proportion_df$Storage))))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units)

  return(list(AreaArboriGather = sum(diet$area_req_village),
              diet = diet))


}
}



##' Setup the general meat diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_pasture
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares for pasture to sustain the animal herd) and a data.frame that supplies the individual values
##' @export
setup_diet_pasture <- function(population,
                               food_df,
                               kcal_req_human_year
                               ) {

  kcal_req_village_year <- kcal_req_human_year * population

  diet <- pasture_selector_kcal(food_df) %>%
    nd_herd(input_animals = .,
            kcal_req_village_year = kcal_req_village_year,
            proportion = .$Proportion)

  return(list(AreaPasture = sum(diet$area_req_village),
              diet = diet))
}


##' Setup the general game diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_game
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_game <- function(population,
                            food_df,
                            kcal_req_human_year) {

  proportion_df <- game_selector_kcal(food_df)

  diet <- proportion_df %>%
    dplyr::mutate(
      Kcal_requirements_percapita = c(
        Proportion * kcal_req_human_year
      ),
      kcal_req_village_year = population * Kcal_requirements_percapita,
      meat_yield_kg = meat_yield,
      meat_yield_kcal_slaughtered = meat_yield_kg * calories,
      calories_slaughter =
        kcal_req_village_year * (Proportion * (1/nrow(proportion_df))),
      number_req_for_calories =
        ceiling(calories_slaughter / meat_yield_kcal_slaughtered)
      )

  return(list(diet = diet))
}





##' Calculate herd characteristics when nothing specific is known
##'
##' This is a small helper function that is called when there are no specific information or empirical evidences to calculate the village meat requirements. To generate more realistic results, the number of required animals is rounded up to the nearest whole number. The function imports the data on animals and animal_products and takes the mean of those values; besides, fodder-plants are imported and all those plants that are also crops are removed from the dataset
##' @title nd_herd
##' @param input_animals The animals input of the data.frame
##' @param kcal_req_village_year The kcal requirements of the village per year
##' @param proportion The proportion of the consumed foodtype in \%
##' @return A data.frame
nd_herd <- function(input_animals, kcal_req_village_year, proportion) {
  data(animals, package = "LandUseQuantifieR")
  data(animal_products, package = "LandUseQuantifieR")
  data(plants, package = "LandUseQuantifieR")

  fodder <- plants %>%
    dplyr::filter(type=="fodder_crops") %>%
    dplyr::filter(species != "barley",
                  species != "emmer",
                  species != "einkorn",
                  species != "millet",
                  species != "lentil")

  selected_animals <- animals %>%
    dplyr::filter(is.element(animal, input_animals$Product)) %>%
    dplyr::left_join(y = input_animals,
                     by = c("animal" = "Product")) %>%
    dplyr::group_by(animal)

  nd_mixed_animal <- dplyr::data_frame(
    animal = selected_animals$animal,
    type = selected_animals$type.x,
    weight = selected_animals$weight,
    Prop_herd = selected_animals$herd_composition,
    calory_requirements = selected_animals$calory_requirements,
    meat_yield_factor = selected_animals$meat_yield_factor,
    meat_yield = selected_animals$meat_yield,
    Slaughter = selected_animals$slaughter_factor,
    slaughter_factor = .3,
    meat_yield_kg = weight * meat_yield_factor,
    meat_yield_kcal_slaughtered = meat_yield_kg * selected_animals$calories,
    calories_slaughter =
      kcal_req_village_year * selected_animals$Proportion * Slaughter,
    number_req_for_calories =
      ceiling(calories_slaughter / meat_yield_kcal_slaughtered),
    number_req_supply_meat =
      ceiling(number_req_for_calories / slaughter_factor * Prop_herd),
    total_herd =
      number_req_supply_meat + number_req_for_calories,
    Kcal_animal_a =
      (calory_requirements * 365) * total_herd,
    area_req_village =
      Kcal_animal_a / (mean(fodder$calories) * mean(fodder$productivity))
  )
  return(nd_mixed_animal)
}


##' Setup the general milk characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_milk
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_milk <-  function(population,
                             food_df,
                             kcal_req_human_year) {

    data(milk, package = "LandUseQuantifieR")
    data(plants, package = "LandUseQuantifieR")


    proportion_df <- milk_selector_kcal(food_df)


    fodder <- plants %>%
      dplyr::filter(type=="fodder_crops") %>%
      dplyr::filter(species != "barley",
                    species != "emmer",
                    species != "einkorn",
                    species != "millet",
                    species != "lentil")


    diet <- proportion_df %>%
      dplyr::mutate(
        Kcal_requirements_percapita = c(
          Proportion * kcal_req_human_year
        ),
        kcal_req_village_year = population * Kcal_requirements_percapita,
        milk_prod = proportion_df$milk_per_indiv_and_year,
        milk_cal = proportion_df$colories,
        milk_kcal_per_indv_and_year = milk_prod * milk_cal,
        req_calories_milk =
          kcal_req_village_year * Proportion,
        number_individuals_req_for_calories =
          ceiling(req_calories_milk / milk_kcal_per_indv_and_year),
        kcal_req_milk_a = number_individuals_req_for_calories * (proportion_df$calory_req_day_individual * 365),
        area_req_village_milk =
          kcal_req_milk_a / (mean(fodder$calories) * mean(fodder$productivity))
      )

    return(list(AreaMilk = sum(diet$area_req_village_milk),
                diet = diet))
  }

##' Setup the general cheese characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_cheese
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_cheese <- function(population,
                              food_df,
                              kcal_req_human_year) {

    data(cheese, package = "LandUseQuantifieR")
    data(plants, package = "LandUseQuantifieR")


    proportion_df <- cheese_selector_kcal(food_df)


    fodder <- plants %>%
      dplyr::filter(type=="fodder_crops") %>%
      dplyr::filter(species != "barley",
                    species != "emmer",
                    species != "einkorn",
                    species != "millet",
                    species != "lentil")


    diet <- proportion_df %>%
      dplyr::mutate(
        Kcal_requirements_percapita = c(
          Proportion * kcal_req_human_year
        ),
        kcal_req_village_year = population * Kcal_requirements_percapita,

        caloriese_per_kg = proportion_df$calories_per_kg,
        kg_cheese_per_individ_and_year = (proportion_df$milk_per_indiv_and_year / proportion_df$liter_milk_needed_for_one_kg_cheese),
        cheese_kcal_per_individ_and_year = caloriese_per_kg * kg_cheese_per_individ_and_year,

        req_calories_cheese =
          kcal_req_village_year * Proportion,

        number_individuals_req_for_calories =
          ceiling(req_calories_cheese / cheese_kcal_per_individ_and_year),


        kcal_req_cheese_a = number_individuals_req_for_calories * (proportion_df$calory_req_day_individual * 365),

        area_req_village_cheese =
          kcal_req_cheese_a / (mean(fodder$calories) * mean(fodder$productivity))
      )

    return(list(AreaCheese = sum(diet$area_req_village_cheese),
                diet = diet))
  }

##' Setup the auxiliary animals
##'
##' This function sets up the kcal etc. values for auxiliary animals in form of a tibble
##' @title setup_auxiliary_animals_kcal
##' @param population The number of people living in the village; default 3800
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param kcal_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @param aux_animal The type of auxiliary animals used; default "bull"
##' @param ... further arguments passed to another function
##' @return a tibble
##' @export

setup_auxiliary_animals_kcal <- function(population,
                                    kcal_req_human_year,
                                    aux_animal,
                                    food_df,
                                    ...) {


  data(aux_animals, package = "LandUseQuantifieR")
  data(plants, package = "LandUseQuantifieR")

  crops <- setup_diet_crops(population,
                            food_df,
                            kcal_req_human_year,
                            ...)

  fodder <- plants %>%
    dplyr::filter(type=="fodder_crops") %>%
    dplyr::filter(species != "barley",
                  species != "emmer",
                  species != "einkorn",
                  species != "millet",
                  species != "lentil")

  aux_animals <- aux_animals %>%
    dplyr::filter(aux_animals$type %in% get("aux_animal"))

  auxiliary_animals <- dplyr::data_frame(
    Auxiliary_Animal = aux_animals$type,
    Area_ploughed_day = aux_animals$Area_ploughed_day_ha, #Halstead 2014
    land_req_ploughing = (crops$AreaCrops * .5),
    teams_req = ceiling(land_req_ploughing /(Area_ploughed_day * 60)),
    kcal_per_animal_year = aux_animals$calory_req_day_individual * 365,
    total_animal_village = teams_req * 2,
    kcal_year = (kcal_per_animal_year * total_animal_village),
    area_req_aux_animals =
      kcal_year / (mean(fodder$calories) * mean(fodder$productivity))
  )


  return(auxiliary_animals)
}


##' Convert a data frame to a lower case
##'
##' This is a small helper function that is called data_checker_kcal and it converts the data given in the food_df into lower case
##' @title data_checker_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

data_checker_kcal <- function(food_df) {
  food_df %<>%
    lapply(tolower) %>%
    dplyr::as_data_frame() %>%
    dplyr::mutate(Proportion = as.numeric(Proportion))
  return(food_df)
}

##' Combining, filtering and selecting data sets
##'
##' This small function called abori_selector_kcal adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title crop_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

crop_selector_kcal <- function(food_df) {
  data(plants, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_kcal %>%
    dplyr::left_join(
      x = .,
      y = plants,
      by = c("Product" = "species")) %>%
    dplyr::filter(grepl(pattern = "cereals|legumes",
                        x = type)) %>%
    dplyr::select(-reference_calories, -reference_productivity)

  return(food_df)
}

##' Combining, filtering and selecting data sets
##'
##' This small function called abori_selector_kcal adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title abori_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

arbori_selector_kcal <- function(food_df) {
  data(plants, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_kcal %>%
    dplyr::left_join(
      x = .,
      y = plants,
      by = c("Product" = "species")) %>%
    dplyr::filter(type == "arboriculture/gathered") %>%
    dplyr::select(-reference_calories, -reference_productivity)

  return(food_df)
}

##' checking the spelling of the animal data input
##'
##' This is a small helper function that is called spelling_checker_kcal and it allows the user to use plural or singular for data input
##' @title spelling_checker_kcal
##' @param animal_name The name of the animal
##' @return Parameter animal_name
spelling_checker_kcal <- function(animal_name) {
  animal_name <- ifelse(test = animal_name == "pig",
                         yes = "pigs",
                         no = animal_name)
  animal_name <- ifelse(test = animal_name == "goat",
                         yes = "goats",
                         no = animal_name)
  animal_name <- ifelse(test = animal_name == "cattles",
                         yes = "cattle",
                         no = animal_name)
  return(animal_name)
  }

##' Combining, filtering, selecting and renaming data sets
##'
##' This small function called pasture_selector adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title pasture_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

pasture_selector_kcal <- function(food_df) {
  data(animal_products, package = "LandUseQuantifieR")

  food_df %<>%
    data_checker_kcal %>%
    dplyr::mutate(Product = spelling_checker_kcal(Product)) %>%
    dplyr::left_join(
      x = .,
      y = animal_products,
      by = c("Product" = "animal")) %>%
    dplyr::filter(product == "meat") %>%
    dplyr::select(-reference_calories) %>%
    dplyr::rename(type = product)
  return(food_df)
}

##' Combining and selecting data sets
##'
##' This small function called game_selector_kcal adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title game_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

game_selector_kcal <- function(food_df) {
  data(game, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_kcal %>%
    dplyr::left_join(
      x = .,
      y = game,
      by = c("Product" = "animal")) %>%
    dplyr::select(-references_calories, -references_weight) %>%
    na.omit

  return(food_df)
}

##' Combining and selecting data sets
##'
##' This small function called milk_selector_kcal adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title milk_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

milk_selector_kcal <- function(food_df) {
  data(milk, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_kcal %>%
    dplyr::left_join(
      x = .,
      y = milk,
      by = c("Product" = "product")) %>%
    dplyr::select(-reference) %>%
    na.omit

  return(food_df)
}


##' Combining and selecting data sets
##'
##' This small function called cheese_selector_kcal adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title cheese_selector_kcal
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

cheese_selector_kcal <- function(food_df) {
  data(cheese, package = "LandUseQuantifieR")

  food_df %<>%
    data_checker_kcal %>%
    dplyr::left_join(
      x = .,
      y = cheese,
      by = c("Product" = "product")) %>%
    dplyr::select(-reference_calories) %>%
    na.omit


  return(food_df)
}




##' Setup of the kcal etc. values for wine
##'
##' This function sets up the kcal etc. values for wine in form of a tibble
##' @title setup_wine_kcal
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param ... Further arguments passed to other functions
##' @return A tibble
##' @export
setup_wine <- function(population,
                       food_df,
                       ...) {

  kcal_human_year <- setup_population(population,
                                      ...)$KcalHumanYear

  data(plants, package = "LandUseQuantifieR")

  wine_prod <- plants %>%
  dplyr::filter(species == "wine")

  wine <- dplyr::data_frame(
    Productivity = wine_prod$productivity,
    Calories = wine_prod$calories,
    EnergyPerArea = Productivity * Calories,
    PropDiet = food_df$Proportion[food_df$Product=="wine"],
    kcal_person_a = PropDiet *  kcal_human_year,
    kcal_ha_net = EnergyPerArea,
    area_person = kcal_person_a / kcal_ha_net,
    area_village = area_person * population,
    yield = area_village * Productivity)

  return(wine)
}



##' Setup of the kcal etc. values for olive_oil
##'
##' This function sets up the kcal etc. values for olive_oil in form of a tibble
##' @title setup_olive_oil_kcal
##' @param population The number of people living in a village
##' @param households The number of households; default: population / 5, where 5 is the number of people living in a household
##' @param olive_oil_storage The percentage of the yield that is stored
##' @param rich_people_factor A factor to reflect the higher consumption of rich residents
##' @param ... Further arguments passed to other functions
##' @return A tibble
##' @export
setup_olive_oil <- function(population,
                            households,
                            olive_oil_storage = .25,
                            rich_people_factor = .66,
                            ...) {

  kcal_human_year <- setup_population(population,
                                      ...)$KcalHumanYear

  data(plants, package = "LandUseQuantifieR")

  olive_oil_production <- plants %>%
    dplyr::filter(species == "olive_oil")

  olive_oil <- dplyr::data_frame(
    Productivity = olive_oil_production$productivity,
    oil_bathing = 2.5,
    oil_lighting = (households * 50) / population,
    area_bathing = oil_bathing / (Productivity * (1 - olive_oil_storage)),
    area_lighting = oil_lighting / (Productivity * (1 - olive_oil_storage)),
    area_village = (population * olive_oil_storage) + (area_bathing + area_lighting) * population,
    yield = (area_village * rich_people_factor) * Productivity)

  return(olive_oil)
}


##' Setup of the ceramics production
##'
##' This function sets up the required wood for ceramic production
##' @title setup_ceramics_kcal
##' @param population The number of people living in the village
##' @param food_df The product and the proportion of the consumed food
##' @param forest_type The type of the forest; choose between "oak_mixed_forest" and "olive_mixed_forest"; default "oak_mixed_forest"
##' @param households The number of households; default: population / 5, where 5 is the number of people living in a household
##' @param olive_oil_yield The yield of the olive production
##' @param ... Further arguments passed to other functions
##' @return A tibble
##' @export
setup_ceramics_kcal <- function(population,
                           forest_type,
                           food_df,
                           households,
                           olive_oil_yield,
                           ...) {

  productivity_tha <- setup_wood_consumption(population,
                                             forest_type,
                                             ...
                                             )$productivity_tha

  productivity_kgha <- setup_wood_consumption(population,
                                              forest_type,
                                              ...
                                              )$productivity_tha * 1000

  wine_yield <- if ("wine" %in% food_df$Product)
                    {setup_wine(population,
                                food_df,
                                ...)$yield}
                else {(0)}



  data(ceramics_production, package = "LandUseQuantifieR")

  ceramics <- dplyr::data_frame(
    vessels_person = ceramics_production$vessels_person, # Weiberg et al. (in prep.)
    vessels_village = ceramics_production$vessels_person * population,
    mean_weight_vessel_kg = ceramics_production$mean_weight_vessel_kg,
    mean_weight_wine_amphora_kg = ceramics_production$mean_weight_wine_amphora_kg,
    mean_weight_oil_amphora_kg = ceramics_production$mean_weight_oil_amphora_kg,
    ratio_wood_ceramics = ceramics_production$ratio_wood_ceramics,
    amphora_production_wine = ((wine_yield * .5) / 2) / 21.6,
    amphora_production_olive_oil = olive_oil_yield / 39.4,
    weight_ceramics = (vessels_village * mean_weight_vessel_kg) +
      (amphora_production_wine * mean_weight_wine_amphora_kg) +
      (amphora_production_olive_oil * mean_weight_oil_amphora_kg),
    wood_req_ceramics = weight_ceramics * ratio_wood_ceramics,
    area_woodlot_ceramics = wood_req_ceramics / productivity_kgha)

  return(ceramics)
}
