##' Calculate the protein requirements of a village
##'
##' Calculate the protein requirements of a village based on a given
##' population size
##'
##' This functions is a wrapper for more comprehensive functions calculating the protein (g) requirements of a village
##'
##' @title setup_protein_req
##' @param population The number of people living in a village
##' @param protein_requirement optional; default NULL reference: \url{https://www.dge.de/wissenschaft/referenzwerte/protein/}
##' @return A list with the elements: Population, ProteinHuman, ProteinHumanYear, ProteinVillageYear
##' @export
setup_protein_req <- function(population,
                              protein_requirement = NULL
                              ) {

  data(protein_req_age, package = "LandUseQuantifieR")

  if (!is.null(protein_requirement)) {
    protein_human <- protein_requirement
  } else {
        protein_human <- protein_req_age %>%
      dplyr::filter(as.numeric(age) > 10,
                    as.numeric(age) < 50) %>%
      dplyr::select(male_g_day, male_g_day) %>%
      sapply(FUN = mean) %>%
      mean(.)
  }

  protein_human_year <- protein_human * 365
  protein_village_year <- protein_human_year * population

  return(list(
    "Population" = population,
    "ProteinHuman" = protein_human,
    "ProteinHumanYear" = protein_human_year,
    "ProteinVillageYear" = protein_village_year))

}

##' Calculate the protein requirements of a village based on number, age, sex and activity level
##'
##' Calculate the protein requirements of a village based on number, age, sex and activity level based on a data.frame containing these information
##'
##' This functions uses more detailed demographic informations to caluculate the yearly protein requirements of a village. To be able to do this, the data has to be stored in a data.frame.
##'
##' @title setup_population_detailed_protein
##' @param population A data.frame containing informations about number, age and sex of each demographic group
##' @return A list with the elements: Population, ProtVillage, ProtHumanYear, ProtVillageyear
##'
##' @importFrom dplyr "%>%"
##' @importFrom dplyr "mutate"
##' @importFrom dplyr "summarize"
##'
##' @export

setup_population_detailed_protein <- function(population
                                      ) {

  data(protein_req_age_long,  package = "LandUseQuantifieR")

  population$age <- as.character(population$age)
  population$sex <- as.character(population$sex)

  population_df <- population

  tmp <- dplyr::left_join(population_df, protein_req_age_long,
                          by = c("age", "sex"))
  village_prot <- tmp %>%
    mutate(total_prot = number * protein_req_g) %>%
    summarize(sum_village_prot = sum(total_prot, na.rm = TRUE))

  population_number <- dplyr::summarize(population_df, sum_number = sum(number,  na.rm = TRUE))

  prot_village_year <- village_prot$sum_village_prot * 365

  prot_human_year <- prot_village_year/population_number$sum_number

  return(list(
    "Population" = population_number$sum_number,
    "ProtVillage" = village_prot$sum_village_prot,
    "ProtHumanYear" = prot_human_year,
    "ProtVillageyear" = prot_village_year))

}


##' Setup the crop and legume diet characteristics based on protein requiremements
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_crops_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita protein requirement of the year; if nothing is supplied, it is calculated based on setup_protein_req function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_crops_protein <- function(population,
                                     food_df,
                                     protein_req_human_year) {

  proportion_df <- crop_selector_protein(food_df)
if (ncol(food_df) < 3) {

  diet <- proportion_df %>%
    dplyr::mutate(
      Protein_requirements_percapita = c(
        Proportion * protein_req_human_year
      ),
      area_req_percapita = c(
        Protein_requirements_percapita / ((productivity * protein) * (1 - (proportion_df$planting + proportion_df$waste_loss + proportion_df$storage)))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units
      )

  return(list(AreaCrops = sum(diet$area_req_village),
              diet = diet))

} else {

  diet <- proportion_df %>%
    dplyr::mutate(
      Protein_requirements_percapita = c(
        Proportion * protein_req_human_year
      ),
      area_req_percapita = c(
       Protein_requirements_percapita / ((productivity * protein) * (1 - (as.numeric(proportion_df$Planting) + as.numeric(proportion_df$Waste_loss) + as.numeric(proportion_df$Storage))))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units)

  return(list(AreaCrops = sum(diet$area_req_village),
              diet = diet))


}

}

##' Setup the general arboriculture and gathered plants diet characteristics based on protein requiremements
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_arbori_gather_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita protein requirement of the year; if nothing is supplied, it is calculated based on setup_protein_req function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_arbori_gather_protein <- function(population,
                                             food_df,
                                             protein_req_human_year) {

  proportion_df <- arbori_selector_protein(food_df)


if (ncol(food_df) < 3) {

  diet <- proportion_df %>%
    dplyr::mutate(
      Protein_requirements_percapita = c(
        Proportion * protein_req_human_year
      ),
      area_req_percapita = c(
        Protein_requirements_percapita / ((productivity * protein) * (1 - (proportion_df$planting + proportion_df$waste_loss + proportion_df$storage)))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units
      )

  return(list(AreaArboriGather = sum(diet$area_req_village),
              diet = diet))

} else {

  diet <- proportion_df %>%
    dplyr::mutate(
      Protein_requirements_percapita = c(
        Proportion * protein_req_human_year
      ),
      area_req_percapita = c(
        Protein_requirements_percapita / ((productivity * protein) * (1 - (as.numeric(proportion_df$Planting) + as.numeric(proportion_df$Waste_loss) + as.numeric(proportion_df$Storage))))
      ),
      area_req_village = c(
        area_req_percapita * population
      ),
      yield = c(area_req_village * productivity
      ),
      yield_unit = yield_units)

  return(list(AreaArboriGather = sum(diet$area_req_village),
              diet = diet))


}
}

##' Setup the general meat diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations;
##' @title setup_diet_pasture_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita protein requirement of the year; if nothing is supplied, it is calculated based on setup_protein_req function
##' @return A list with a numeric (required hectares for pasture to sustain the animal herd) and a data.frame that supplies the individual values
##' @export
setup_diet_pasture_protein <- function(population,
                                       food_df,
                                       protein_req_human_year) {

  protein_req_village_year <- protein_req_human_year * population

  diet <- pasture_selector_protein(food_df) %>%
    nd_herd_protein(input_animals = .,
                    protein_req_village_year = protein_req_village_year,
                    proportion = .$Proportion)

  return(list(AreaPasture = sum(diet$area_req_village),
              diet = diet))
}


##' Setup the general game diet characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_game_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita protein requirement of the year; if nothing is supplied, it is calculated based on setup_protein_req function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_game_protein <- function(population,
                                    food_df,
                                    protein_req_human_year) {

  proportion_df <- game_selector_protein(food_df)

  diet <- proportion_df %>%
    dplyr::mutate(
      protein_requirements_percapita = c(
        Proportion * protein_req_human_year
      ),
      protein_req_village_year = population * protein_requirements_percapita,
      meat_yield_kg = meat_yield,
      meat_yield_protein_slaughtered = meat_yield_kg * protein,
      protein_slaughter =
        protein_req_village_year * (Proportion * (1/nrow(proportion_df))),
      number_req_for_protein =
        ceiling(protein_slaughter / meat_yield_protein_slaughtered)
      )

  return(list(diet = diet))
}





##' Calculate herd characteristics when nothing specific is known
##'
##' This is a small helper function that is called when there are no specific information or empirical evidences to calculate the village meat requirements. To generate more realistic results, the number of required animals is rounded up to the nearest whole number. The function imports the data on animals and animal_products and takes the mean of those values; besides, fodder-plants are imported and all those plants that are also crops are removed from the dataset
##' @title nd_herd_protein
##' @param input_animals The animals input of the data.frame
##' @param protein_req_village_year The kcal requirements of the village per year
##' @param proportion The proportion of the consumed foodtype in \%
##' @return A data.frame
nd_herd_protein <- function(input_animals, protein_req_village_year, proportion) {
  data(animals, package = "LandUseQuantifieR")
  data(animal_products, package = "LandUseQuantifieR")
  data(plants, package = "LandUseQuantifieR")

  fodder <- plants %>%
    dplyr::filter(type=="fodder_crops") %>%
    dplyr::filter(species != "barley",
                  species != "emmer",
                  species != "einkorn",
                  species != "millet",
                  species != "lentil")

  selected_animals <- animals %>%
    dplyr::filter(is.element(animal, input_animals$Product)) %>%
    dplyr::left_join(y = input_animals,
                     by = c("animal" = "Product")) %>%
    dplyr::group_by(animal)

  nd_mixed_animal <- dplyr::data_frame(
    animal = selected_animals$animal,
    type = selected_animals$type.x,
    weight = selected_animals$weight,
    Prop_herd = selected_animals$herd_composition,
    calory_requirements = selected_animals$calory_requirements,
    meat_yield_factor = selected_animals$meat_yield_factor,
    meat_yield = selected_animals$meat_yield,
    Slaughter = selected_animals$slaughter_factor,
    slaughter_factor = .3,
    meat_yield_kg = weight * meat_yield_factor,
    meat_yield_protein_slaughtered = meat_yield_kg * selected_animals$protein,
    protein_slaughter =
      protein_req_village_year * selected_animals$Proportion * Slaughter,
    number_req_for_protein =
      ceiling(protein_slaughter / meat_yield_protein_slaughtered),
    number_req_supply_meat =
      ceiling(number_req_for_protein / slaughter_factor * Prop_herd),
    total_herd =
      number_req_supply_meat + number_req_for_protein,
    Kcal_animal_a =
      (calory_requirements * 365) * total_herd,
    area_req_village =
      Kcal_animal_a / (mean(fodder$calories) * mean(fodder$productivity))
  )
  return(nd_mixed_animal)
}


##' Setup the general milk characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_milk_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_milk_protein <-  function(population,
                                     food_df,
                                     protein_req_human_year) {

    data(milk, package = "LandUseQuantifieR")
    data(plants, package = "LandUseQuantifieR")


    proportion_df <- milk_selector_protein(food_df)


    fodder <- plants %>%
      dplyr::filter(type=="fodder_crops") %>%
      dplyr::filter(species != "barley",
                    species != "emmer",
                    species != "einkorn",
                    species != "millet",
                    species != "lentil")


    diet <- proportion_df %>%
      dplyr::mutate(
        protein_requirements_percapita = c(
          Proportion * protein_req_human_year
        ),
        protein_req_village_year = population * protein_requirements_percapita,
        milk_prod = proportion_df$milk_per_indiv_and_year,
        milk_protein = proportion_df$protein,
        milk_protein_per_indv_and_year = milk_prod * milk_protein,
        req_protein_milk =
          protein_req_village_year * Proportion,
        number_individuals_req_for_protein =
          ceiling(req_protein_milk / milk_protein_per_indv_and_year),
        protein_req_milk_a = number_individuals_req_for_protein * (proportion_df$calory_req_day_individual * 365),
        area_req_village_milk =
          protein_req_milk_a / (mean(fodder$calories) * mean(fodder$productivity))
      )

    return(list(AreaMilk = sum(diet$area_req_village_milk),
                diet = diet))
  }

##' Setup the general cheese characteristics
##'
##' This function creates a data.frame of the diet characteristics of a village that is used in subsequent calculations. To generate more realistic results, the number of required animals is rounded up to the nearest whole number;
##' @title setup_diet_cheese_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita kcal requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @return A list with a numeric (required hectares to grow plants to sustain the population) and a data.frame that supplies the individual values
##' @export
setup_diet_cheese_protein <-  function(population,
                                       food_df,
                                       protein_req_human_year) {

    data(cheese, package = "LandUseQuantifieR")
    data(plants, package = "LandUseQuantifieR")


    proportion_df <- cheese_selector_protein(food_df)


    fodder <- plants %>%
      dplyr::filter(type=="fodder_crops") %>%
      dplyr::filter(species != "barley",
                    species != "emmer",
                    species != "einkorn",
                    species != "millet",
                    species != "lentil")


    diet <- proportion_df %>%
      dplyr::mutate(
        protein_requirements_percapita = c(
          Proportion * protein_req_human_year
        ),
        protein_req_village_year = population * protein_requirements_percapita,

        protein_per_kg = proportion_df$protein,
        kg_cheese_per_individ_and_year = (proportion_df$milk_per_indiv_and_year / proportion_df$liter_milk_needed_for_one_kg_cheese),
        cheese_protein_per_individ_and_year = protein_per_kg * kg_cheese_per_individ_and_year,

        req_protein_cheese =
          protein_req_village_year * Proportion,

        number_individuals_req_for_protein =
          ceiling(req_protein_cheese / cheese_protein_per_individ_and_year),


        protein_req_cheese_a = number_individuals_req_for_protein * (proportion_df$calory_req_day_individual * 365),

        area_req_village_cheese =
          protein_req_cheese_a / (mean(fodder$calories) * mean(fodder$productivity))
      )

    return(list(AreaCheese = sum(diet$area_req_village_cheese),
                diet = diet))
  }

##' Setup the auxiliary animals
##'
##' This function sets up the kcal etc. values for auxiliary animals in form of a tibble
##' @title setup_auxiliary_animals_protein
##' @param population The number of people living in the village; default 3800
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param protein_req_human_year The per capita protein requirement of the year; if nothing is supplied, it is calculated based on setup_population function
##' @param aux_animal The type of auxiliary animals used; default "bull"
##' @param ... further arguments passed to another function
##' @return a tibble
##' @export

setup_auxiliary_animals_protein <- function(population,
                                    protein_req_human_year,
                                    aux_animal,
                                    food_df,
                                    ...) {


  data(aux_animals, package = "LandUseQuantifieR")
  data(plants, package = "LandUseQuantifieR")

  crops <- setup_diet_crops_protein(population,
                                    food_df,
                                    protein_req_human_year,
                                    ...)

  fodder <- plants %>%
    dplyr::filter(type=="fodder_crops") %>%
    dplyr::filter(species != "barley",
                  species != "emmer",
                  species != "einkorn",
                  species != "millet",
                  species != "lentil")

  aux_animals <- aux_animals %>%
    dplyr::filter(aux_animals$type %in% get("aux_animal"))

  auxiliary_animals <- dplyr::data_frame(
    Auxiliary_Animal = aux_animals$type,
    Area_ploughed_day = aux_animals$Area_ploughed_day_ha, #Halstead 2014
    land_req_ploughing = (crops$AreaCrops * .5),
    teams_req = ceiling(land_req_ploughing /(Area_ploughed_day * 60)),
    kcal_per_animal_year = aux_animals$calory_req_day_individual * 365,
    total_animal_village = teams_req * 2,
    kcal_year = (kcal_per_animal_year * total_animal_village),
    area_req_aux_animals =
      kcal_year / (mean(fodder$calories) * mean(fodder$productivity))
  )


  return(auxiliary_animals)
}


##' Convert a data frame to a lower case
##'
##' This is a small helper function that is called data_checker_protein and it converts the data given in the food_df into lower case
##' @title data_checker_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

data_checker_protein <- function(food_df) {
  food_df %<>%
    lapply(tolower) %>%
    dplyr::as_data_frame() %>%
    dplyr::mutate(Proportion = as.numeric(Proportion))
  return(food_df)
}

##' Combining, filtering and selecting data sets
##'
##' This small function called abori_selector_protein adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title crop_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

crop_selector_protein <- function(food_df) {
  data(plants, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_protein %>%
    dplyr::left_join(
      x = .,
      y = plants,
      by = c("Product" = "species")) %>%
    dplyr::filter(grepl(pattern = "cereals|legumes",
                        x = type)) %>%
    dplyr::select(-reference_calories, -reference_productivity)

  return(food_df)
}

##' Combining, filtering and selecting data sets
##'
##' This small function called abori_selector adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title abori_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

arbori_selector_protein <- function(food_df) {
  data(plants, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_protein %>%
    dplyr::left_join(
      x = .,
      y = plants,
      by = c("Product" = "species")) %>%
    dplyr::filter(type == "arboriculture/gathered") %>%
    dplyr::select(-reference_calories, -reference_productivity)

  return(food_df)
}

##' checking the spelling of the animal data input
##'
##' This is a small helper function that is called spelling_checker_protein and it allows the user to use plural or singular for data input
##' @title spelling_checker_protein
##' @param animal_name The name of the animal
##' @return Parameter animal_name
spelling_checker_protein <- function(animal_name) {
  animal_name <- ifelse(test = animal_name == "pig",
                         yes = "pigs",
                         no = animal_name)
  animal_name <- ifelse(test = animal_name == "goat",
                         yes = "goats",
                         no = animal_name)
  animal_name <- ifelse(test = animal_name == "cattles",
                         yes = "cattle",
                         no = animal_name)
  return(animal_name)
  }

##' Combining, filtering, selecting and renaming data sets
##'
##' This small function called pasture_selector adds new variables to one dataset from another dataset, filters the data input and selects the references for the users data input from the packages data
##' @title pasture_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

pasture_selector_protein <- function(food_df) {
  data(animal_products, package = "LandUseQuantifieR")

  food_df %<>%
    data_checker_protein %>%
    dplyr::mutate(Product = spelling_checker_protein(Product)) %>%
    dplyr::left_join(
      x = .,
      y = animal_products,
      by = c("Product" = "animal")) %>%
    dplyr::filter(product == "meat") %>%
    dplyr::select(-reference_calories) %>%
    dplyr::rename(type = product)
  return(food_df)
}

##' Combining and selecting data sets
##'
##' This small function called game_selector_protein adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title game_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

game_selector_protein <- function(food_df) {
  data(game, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_protein %>%
    dplyr::left_join(
      x = .,
      y = game,
      by = c("Product" = "animal")) %>%
    dplyr::select(-references_calories, -references_weight) %>%
    na.omit

  return(food_df)
}

##' Combining and selecting data sets
##'
##' This small function called milk_selector adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title milk_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

milk_selector_protein <- function(food_df) {
  data(milk, package = "LandUseQuantifieR")
  food_df %<>%
    data_checker_protein %>%
    dplyr::left_join(
      x = .,
      y = milk,
      by = c("Product" = "product")) %>%
    dplyr::select(-reference) %>%
    na.omit

  return(food_df)
}


##' Combining and selecting data sets
##'
##' This small function called cheese_selector_protein adds new variables to one dataset from another dataset and selects the references for the users data input from the packages data
##' @title cheese_selector_protein
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @return Parameter food_df

cheese_selector_protein <- function(food_df) {
  data(cheese, package = "LandUseQuantifieR")

  food_df %<>%
    data_checker_protein %>%
    dplyr::left_join(
      x = .,
      y = cheese,
      by = c("Product" = "product")) %>%
    dplyr::select(-reference_calories) %>%
    na.omit


  return(food_df)
}

##' Setup of the protein etc. values for wine
##'
##' This function sets up the kcal etc. values for wine in form of a tibble
##' @title setup_wine_protein
##' @param population The number of people living in a village
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param ... Further arguments passed to other functions
##' @return A tibble
##' @export
setup_wine_protein <- function(population,
                               food_df,
                               ...) {

  protein_human_year <- setup_protein_req(population,
                                          ...)$ProteinHumanYear

  data(plants, package = "LandUseQuantifieR")

  wine_prod <- plants %>%
  dplyr::filter(species == "wine")

  wine <- dplyr::data_frame(
    Productivity = wine_prod$productivity,
    Protein = wine_prod$protein,
    EnergyPerArea = Productivity * Protein,
    PropDiet = food_df$Proportion[food_df$Product=="wine"],
    protein_person_a = PropDiet *  protein_human_year,
    protein_ha_net = EnergyPerArea,
    area_person = protein_person_a / protein_ha_net,
    area_village = area_person * population,
    yield = area_village * Productivity)

  return(wine)
}

##' Setup of the ceramics production using protein
##'
##' This function sets up the required wood for ceramic production
##' @title setup_ceramics_protein
##' @param population The number of people living in the village
##' @param food_df The product and the proportion of the consumed food
##' @param forest_type The type of the forest; choose between "oak_mixed_forest" and "olive_mixed_forest"; default "oak_mixed_forest"
##' @param households The number of households; default: population / 5, where 5 is the number of people living in a household
##' @param olive_oil_yield The yield of the olive production
##' @param ... Further arguments passed to other functions
##' @return A tibble
##' @export
setup_ceramics_protein <- function(population,
                                   forest_type,
                                   food_df,
                                   households,
                                   olive_oil_yield,
                                   ...) {

  productivity_tha <- setup_wood_consumption(population,
                                             forest_type,
                                             ...
                                             )$productivity_tha

  productivity_kgha <- setup_wood_consumption(population,
                                              forest_type,
                                              ...
                                              )$productivity_tha * 1000

  wine_yield <- if ("wine" %in% food_df$Product)
                    {setup_wine_protein(population,
                                        food_df,
                                        ...)$yield}
                else {(0)}



  data(ceramics_production, package = "LandUseQuantifieR")

  ceramics <- dplyr::data_frame(
    vessels_person = ceramics_production$vessels_person, # Weiberg et al. (in prep.)
    vessels_village = ceramics_production$vessels_person * population,
    mean_weight_vessel_kg = ceramics_production$mean_weight_vessel_kg,
    mean_weight_wine_amphora_kg = ceramics_production$mean_weight_wine_amphora_kg,
    mean_weight_oil_amphora_kg = ceramics_production$mean_weight_oil_amphora_kg,
    ratio_wood_ceramics = ceramics_production$ratio_wood_ceramics,
    amphora_production_wine = ((wine_yield * .5) / 2) / 21.6,
    amphora_production_olive_oil = olive_oil_yield / 39.4,
    weight_ceramics = (vessels_village * mean_weight_vessel_kg) +
      (amphora_production_wine * mean_weight_wine_amphora_kg) +
      (amphora_production_olive_oil * mean_weight_oil_amphora_kg),
    wood_req_ceramics = weight_ceramics * ratio_wood_ceramics,
    area_woodlot_ceramics = wood_req_ceramics / productivity_kgha)

  return(ceramics)
}

