
##' Summarize_areas_protein
##'
##' Bring all function calculations together
##' @title summarize_areas_protein
##' @param population The number of people living in a village; default 3800
##' @param protein_requirement The protein a human requires per day; default NULL
##' @param household_people The number of people per household; default 5
##' @param food_df The consumed food and the proportion in \% of the consumed food
##' @param aux_animal The type of auxiliary animals used; default "bull"
##' @param forest_type The type of the forest; choose between "oak_mixed_forest" and "olive_mixed_forest"; default "oak_mixed_forest"
##' @param bronze Whether the population melted/used bronze; default FALSE
##' @param iron Whether the population melted/used iron; default FALSE
##' @param ceramics Whether the population produced/used ceramic; default FALSE
##' @param olive_oil Whether the population produced olive oil; default FALSE
##' @param flax Whether the population needs flax; default FALSE
##' @param ... Further arguments passed to other functions
##' @return A tibble
##'
##' @importFrom magrittr "%>%"
##' @importFrom magrittr "%<>%"
##' @export
summarize_areas_protein <- function(population = 3800,
                                    protein_requirement = NULL,
                                    household_people = 5.00,
                                    food_df,
                                    aux_animal = "bull",
                                    forest_type = "oak_mixed_forest",
                                    bronze = FALSE,
                                    iron = FALSE,
                                    ceramics = FALSE,
                                    olive_oil = FALSE,
                                    flax = FALSE,
                                    ...){

if (is.numeric(population)) {
  
  households <- population / household_people

   if (is.null(protein_requirement)) {
    protein_req_human_year <- setup_protein_req(
      population = population)$ProteinHumanYear
  } else {
    protein_req_human_year <- protein_requirement * 365
  }
}
  else {
  protein_req_human_year <-
    setup_population_detailed_protein(
      population =  population)$ProtHumanYear

  population <- setup_population_detailed_protein(
    population =  population)$Population

  households <- population / household_people
}
  
  crops <- setup_diet_crops_protein(
    population = population,
    protein_req_human_year = protein_req_human_year,
    food_df = food_df)

  arbori <- setup_diet_arbori_gather_protein(
    population = population,
    protein_req_human_year = protein_req_human_year,
    food_df = food_df)

  pasture <- setup_diet_pasture_protein(
    population = population,
    food_df = food_df,
    protein_req_human_year = protein_req_human_year)

  aux_animals <- setup_auxiliary_animals_protein(
    population = population,
    protein_req_human_year = protein_req_human_year,
    food_df = food_df,
    aux_animal = aux_animal)

  game <- setup_diet_game_protein(
    population = population,
    food_df = food_df,
    protein_req_human_year = protein_req_human_year)

  milk <- setup_diet_milk_protein(
    population = population,
    food_df = food_df,
    protein_req_human_year = protein_req_human_year)

  cheese <- setup_diet_cheese_protein(
    population = population,
    food_df = food_df,
    protein_req_human_year = protein_req_human_year)

  wood <- setup_wood_consumption(
    population = population,
    forest_type = forest_type)

    if (isTRUE(bronze)){
      bronze <- setup_bronze(
        population = population,
        forest_type = forest_type)}
      else{bronze <- setup_bronze(
        population = 0,
        forest_type = forest_type)}

    if (isTRUE(iron)){
      iron <- setup_iron(
        population = population,
        forest_type = forest_type)}
      else {iron <- setup_iron(
        population = 0,
        forest_type = forest_type)}

    if (isTRUE(ceramics) & isTRUE(olive_oil)){
      ceramics <- setup_ceramics_protein(
        population = population,
        forest_type = forest_type,
        food_df = food_df,
        households = households,
        olive_oil_yield = setup_olive_oil(population,
                                          households,
                                          olive_oil_storage = .25,
                                          rich_people_factor = .66,
                                          ...)$yield)}

  else if (isTRUE(ceramics) & (olive_oil == FALSE)){
        ceramics <- setup_ceramics_protein(
                    population = population,
                    forest_type = forest_type,
                    food_df = food_df,
                    households = households,
                    olive_oil_yield = 0)}
  else {ceramics <- setup_ceramics_protein(
                    population = 0,
                    forest_type = forest_type,
                    food_df = food_df,
                    households = households,
                    olive_oil_yield = 0)}


    if (isTRUE(olive_oil)){
      olive_oil <- setup_olive_oil(
        population = population,
        households = population / household_people)}
      else {olive_oil <- setup_olive_oil(
        population = 0,
        households = 0)}

    if (isTRUE(flax)){
      flax <- setup_flax(
        population = population)}
      else {flax <- setup_flax(
        population = 0)}




  total_ha <- dplyr::data_frame(
    Category = c("Settlement",
                 "Crops",
                 "Arboriculture/Gathered",
                 "Pasture",
                 "Wood",
                 if (flax$area_req > 0){"Flax"}
                 ),
    Area_ha = c(area_village(population = population),
                crops$AreaCrops,
                arbori$AreaArboriGather,
                pasture$AreaPasture + milk$AreaMilk + cheese$AreaCheese + aux_animals$area_req_aux_animals,
                wood$area_wood_production_ha +
                  bronze$area_woodlot +
                  ceramics$area_woodlot_ceramics +
                  iron$area_woodlot_iron,
                if (flax$area_req > 0){flax$area_req}
                ),
    Area_prop = Area_ha/sum(Area_ha))

  output_list <- list("Area Requirements" = total_ha,
                      "Crops" = crops$diet %>%
                        dplyr::select(Product,
                                      Proportion,
                                      type,
                                      productivity,
                                      produc_units,
                                      protein,
                                      protein_unit,
                                      area_req_village),
                      "Arboriculture/Gathered" = arbori$diet %>%
                        dplyr::select(Product,
                                      Proportion,
                                      type,
                                      productivity,
                                      produc_units,
                                      protein,
                                      protein_unit,
                                      area_req_village),
                      "Domestic Animals" = pasture$diet %>%
                        dplyr::select(animal,
                                      type,
                                      Prop_herd,
                                      number_req_for_protein,
                                      number_req_supply_meat,
                                      area_req_village),
                      "Auxiliary Animals" = aux_animals %>%
                        dplyr::select(-kcal_per_animal_year,
                                      -kcal_year),
                      "Milk" = milk$diet %>%
                        dplyr::select(Product,
                                      Proportion,
                                      protein,
                                      number_individuals_req_for_protein,
                                      area_req_village_milk),
                      "Cheese" = cheese$diet %>%
                        dplyr::select(Product,
                                      Proportion,
                                      protein,
                                      number_individuals_req_for_protein,
                                      area_req_village_cheese),
                      "Game" = game$diet %>%
                        dplyr::select(Product,
                                      Proportion,
                                      type,
                                      protein,
                                      number_req_for_protein),
                      "Wood consumption" = wood %>%
                        dplyr::select(consumption_wood_person_a,
                               consumption_fuelwood_person_a_kg,
                               req_person_a,
                               req_village_a,
                               area_wood_production_m2,
                               area_wood_production_ha),
                      "Bronze Production" = if (bronze$wood_req > 0){bronze %>%
                                                                    dplyr::select(wood_req,
                                                                           area_woodlot)},
                      "Iron Production" = if (iron$area_woodlot_iron > 0){iron %>%
                                                                         dplyr::select(req_village_iron_kg,
                                                                                area_woodlot_iron)},
                      "Olive Oil" = if (isTRUE(olive_oil$yield > 0)){olive_oil},
                      "Ceramics" = if (ceramics$vessels_village > 0){ceramics %>%
                                                                    dplyr::select(amphora_production_wine,
                                                                           amphora_production_olive_oil,
                                                                           area_woodlot_ceramics)},
                      "Flax" = if (flax$area_req > 0){flax}
                      )

 return(output_list)
}


